@@ -338,8 +338,20 @@ build_fbl_layer <- function(object, data = NULL, level = c(80, 95),
     intvl_mapping$fill_ramp <- intvl_mapping$colour_ramp <- sym(".width")
     intvl_mapping$fill <- intvl_mapping$colour <- col
     
+    qi_marginal <- function(x, .width = 0.95, na.rm = FALSE) {
+      if (!na.rm && anyNA(x)) {
+        return(matrix(c(NA_real_, NA_real_), ncol = 2))
+      }
+      
+      if (utils::packageVersion("distributional") > "0.4.0") {
+        do.call(rbind, lapply(quantile(x, (1 + c(-1, 1) * .width)/2, type = "marginal", na.rm = na.rm), t))
+      } else {
+        do.call(rbind, lapply(quantile(x, (1 + c(-1, 1) * .width)/2, na.rm = na.rm), t))
+      }
+    }
+    
     dist_qi_frame <- function(data, level) {
-      data <- ggdist::median_qi(as_tibble(data), !!sym(distribution_var(data)), .width = level/100)
+      data <- ggdist::point_interval(as_tibble(data), !!sym(distribution_var(data)), .interval = qi_marginal, .width = level/100)
       names(data)[match(".index", names(data))] <- ".response"
       data
     }
@@ -349,7 +361,7 @@ build_fbl_layer <- function(object, data = NULL, level = c(80, 95),
         out[[length(out) + 1L]] <- ggdist::geom_lineribbon(without(intvl_mapping, "colour_ramp"), data = dist_qi_frame(object[single_row[["FALSE"]],], level), ..., inherit.aes = FALSE, key_glyph = draw_key_ribbon)
       }
       if(length(single_row[["TRUE"]]) > 0) {
-        out[[length(out) + 1L]] <- ggdist::stat_interval(intvl_mapping, data = dist_qi_frame(object[single_row[["TRUE"]],], level), ..., inherit.aes = FALSE, key_glyph = draw_key_ribbon)
+        out[[length(out) + 1L]] <- ggdist::geom_interval(intvl_mapping, data = dist_qi_frame(object[single_row[["TRUE"]],], level), orientation = "vertical", ..., inherit.aes = FALSE, key_glyph = draw_key_ribbon)
       }
       out[[length(out) + 1L]] <- ggplot2::labs(fill = col_nm)
     } else {
@@ -357,7 +369,7 @@ build_fbl_layer <- function(object, data = NULL, level = c(80, 95),
         out[[length(out) + 1L]] <- ggdist::geom_lineribbon(without(intvl_mapping, "colour_ramp"), data = dist_qi_frame(object[single_row[["FALSE"]],], level), fill = colour, ..., inherit.aes = FALSE, key_glyph = draw_key_ribbon)
       }
       if(length(single_row[["TRUE"]]) > 0) {
-        out[[length(out) + 1L]] <- ggdist::stat_interval(intvl_mapping, data = dist_qi_frame(object[single_row[["TRUE"]],], level), colour = colour, ..., inherit.aes = FALSE, key_glyph = draw_key_ribbon)
+        out[[length(out) + 1L]] <- ggdist::geom_interval(intvl_mapping, data = dist_qi_frame(object[single_row[["TRUE"]],], level), colour = colour, orientation = "vertical", ..., inherit.aes = FALSE, key_glyph = draw_key_ribbon)
       }
     }
     
